/*

Prepares IPW and employment changes.

----------------------------------------------------------------------------- */

* run programs
run "../../main/do/ipw_pchjobs_pr"

* --------- Changes in exports

* --- Predicted changes in exports from China to US (4-digit industries)

* these data show value of exports from China to partners, by 4-digit industry and year, from 1996-2011 (src: prepare_trade.do)
use "../data_raw/comtrade1998_2011", clear
ren tradevalueus tradevalue

* keep exports to US in 2007, 2010, and 2011
keep if partnercode == 842 & inlist(period, 2007, 2010, 2011)
reshape wide tradevalue, i(rama) j(period)

* each industry's percentage of total exports in 2007
replace tradevalue2007 = 0 if mi(tradevalue2007)
preserve
egen inishare_2007 = pc(tradevalue2007), prop

* total exports to US in 2010 and 2011
egen totalvalue2010 = total(tradevalue2010)
egen totalvalue2011 = total(tradevalue2011)

* predict export value of each industry in 2010 and 2011: total value in year t x industry's share of exports
gen ptradevalue2010 = totalvalue2010 * inishare_2007
gen ptradevalue2011 = totalvalue2011 * inishare_2007

* predicted change in China exports to US from 2007 (delta UC)
gen chexp2010 = ptradevalue2010 - tradevalue2007
gen chexp2011 = ptradevalue2011 - tradevalue2007
keep rama chexp*
tempfile prd_chexp_us_4dig
save `prd_chexp_us_4dig'

* --- Contemporaneous changes in exports from China to US (4-digit industries)
restore
gen chexp2010 = tradevalue2010 - tradevalue2007
gen chexp2011 = tradevalue2011 - tradevalue2007
keep rama chexp*
tempfile con_chexp_us_4dig
save `con_chexp_us_4dig'

* --- Predicted changes in exports from China to Mexico (4-digit industries)
use "../data_raw/comtrade1998_2011", clear
ren tradevalueus tradevalue
keep if partnercode == 484 & inlist(period, 2007, 2010, 2011)
reshape wide tradevalue, i(rama) j(period)

* each industry's percentage of total exports in 2007
egen inishare_2007 = pc(tradevalue2007), prop

* total exports to Mexico in 2010 and 2011
egen totalvalue2010 = total(tradevalue2010)
egen totalvalue2011 = total(tradevalue2011)

* predict export value of each industry in 2010 and 2011: total value in year t x industry's share of exports in 2007
gen ptradevalue2010 = totalvalue2010 * inishare_2007
gen ptradevalue2011 = totalvalue2011 * inishare_2007

* predicted change in China exports to Mexico from 2007
gen chexp2010 = ptradevalue2010 - tradevalue2007
gen chexp2011 = ptradevalue2011 - tradevalue2007
keep rama chexp*
tempfile prd_chexp_mex_4dig
save `prd_chexp_mex_4dig'

* --- Predicted changes in exports from China to US (4-digit industries), upstream-linked industries and downstream-linked industries
use `prd_chexp_us_4dig', clear
gen subs = string(floor(rama / 10))
replace subs="336A" if inlist(rama, 3361, 3362, 3363)
replace subs="336B" if inlist(rama, 3364, 3365, 3366, 3369)

* merge in IO table codes
merge m:1 subs using "../data_raw/subs_usio3digit", assert(using match) keep(match) nogen keepusing(us_io_id3digit)
collapse (sum) chexp*, by(us_io_id3digit)
preserve

* merge with upstream weights
ren us_io_id3digit origin
merge 1:m origin using "../data_prepped/linkage_weights", assert(using match) keep(match) nogen keepusing(share_purchases destination)

* for each destination industry, multiply upstream weights by changes in exports in origin industries and sum over origin industries to get change in exports in upstream industries
collapse (sum) chexp* [aw=share_purchases], by(destination)
ren destination rama
tempfile prd_chexp_us_upstream
save `prd_chexp_us_upstream'

* merge with downstream weights
restore
ren us_io_id3digit destination
merge 1:m destination using "../data_prepped/linkage_weights", assert(using match) keep(match) nogen keepusing(share_sales origin)

* for each origin industry, multiply downstream weights by changes in exports in destination industries and sum over destination industries to get change in exports in downstream industries
collapse (sum) chexp* [aw=share_sales], by(origin)
ren origin rama
tempfile prd_chexp_us_downstream
save `prd_chexp_us_downstream'

* --- Contemporaneous changes in exports from China to OECD (4-digit industries)
use "../data_raw/chinaexpOECDall_rama", clear
keep if inlist(period, 2007, 2010, 2011)
reshape wide tradevalue, i(rama) j(period)
gen chexp2010 = tradevalue2010 - tradevalue2007
gen chexp2011 = tradevalue2011 - tradevalue2007
keep rama chexp*
tempfile con_chexp_oecd_4dig
save `con_chexp_oecd_4dig'

* --- Predicted changes in exports from China to US (6-digit industries)
use "../data_prepped/comtrade1998_2011_6dig", clear
ren tradevalueus tradevalue

* keep exports to US in 2007, 2010, and 2011
keep if partnercode == 842 & inlist(period, 2007, 2010, 2011)
reshape wide tradevalue, i(clase) j(period)

* each industry's percentage of total exports in 2007
replace tradevalue2007 = 0 if mi(tradevalue2007)
egen inishare_2007 = pc(tradevalue2007), prop

* total exports to US in 2010 and 2011
egen totalvalue2010 = total(tradevalue2010)
egen totalvalue2011 = total(tradevalue2011)

* predict export value of each industry in 2010 and 2011: total value in year t x industry's share of exports
gen ptradevalue2010 = totalvalue2010 * inishare_2007
gen ptradevalue2011 = totalvalue2011 * inishare_2007

* predicted change in China exports to US from 2007 (delta UC)
gen chexp2010 = ptradevalue2010 - tradevalue2007
gen chexp2011 = ptradevalue2011 - tradevalue2007
keep clase chexp* tradevalue2007
tempfile prd_chexp_us_6dig
save `prd_chexp_us_6dig'

* ------------------------------------------------------------------------------
* Prepare labor by Mexican municpality x industry

* --- 4-digit industry
use "../../main/data_raw/rama_municipio_totemp_emim20072011_year", clear
keep if inlist(year, 2007, 2010, 2011)
destring rama, replace
gen subs = floor(rama / 10)
preserve
tempfile emp_4dig
preplabor, outfile(`emp_4dig') indcodevar(rama)

* --- 6-digit industry
use "../data_raw/clase_mun_totemp_emim20072011", clear
replace municipio = (1000 * ent) + municipio
keep if inlist(year, 2007, 2010, 2011)
destring clase, replace
gen subs = floor(clase / 1000)
tempfile emp_6dig
preplabor, outfile(`emp_6dig') indcodevar(clase)

* --- 4-digit industry (weight by export orientation)
restore, preserve
ren rama ramadeactividad
gen entidadfederativa = floor(municipio / 1000)
replace municipio = mod(municipio, 1000)
merge m:1 ramadeactividad entidadfederativa municipio using "../data_raw/export_domsales_share_censo2003", keep(master match) nogen keepusing(share_export_censo2004)
ren share_export_censo2004 share_export_censo2003
ren ramadeactividad rama
replace municipio = (1000 * entidadfederativa) + municipio
drop entidadfederativa
replace totemp = totemp * share_export_censo2003
tempfile emp_4dig_exp
preplabor, outfile(`emp_4dig_exp') indcodevar(rama)

* --- 4-digit industry (weight by domestic orientation)
restore
ren rama ramadeactividad
gen entidadfederativa = floor(municipio / 1000)
replace municipio = mod(municipio, 1000)
merge m:1 ramadeactividad entidadfederativa municipio using "../data_raw/export_domsales_share_censo2003", keep(master match) nogen keepusing(share_export_censo2004)
ren share_export_censo2004 share_export_censo2003
ren ramadeactividad rama
replace municipio = (1000 * entidadfederativa) + municipio
drop entidadfederativa
replace totemp = totemp * (1 - share_export_censo2003)
tempfile emp_4dig_dom
preplabor, outfile(`emp_4dig_dom') indcodevar(rama)

* --- Using IO table codes
use `emp_4dig', clear

* merge with IO table codes
gen subs = string(floor(rama / 10))
replace subs="336A" if inlist(rama, 3361, 3362, 3363)
replace subs="336B" if inlist(rama, 3364, 3365, 3366, 3369)
merge m:1 subs using "../data_raw/subs_usio3digit", assert(using match) keep(match) nogen keepusing(us_io_id3digit)
drop rama subs
sort id_mun us_io_id3digit
foreach v of var totemp* natemp* {
    by id_mun us_io_id3digit: egen total_`v' = total(`v'), missing
    replace `v' = total_`v'
    drop total_`v'
}
duplicates drop
ren us_io_id3digit rama
tempfile emp_iocodes
save `emp_iocodes'

* ------------------------------------------------------------------------------
* Merge 2003 labor force and 2007 EMIM manufacturing labor to make denominators

* use 2007 EMIM
use "../../main/data_prepped/lemim07", replace

* merge with 2003 labor
ren id_mun municipio
merge 1:1 municipio using "../../main/data_raw/pop_manpop_municipio.dta", keepusing(L03) nogen
ren municipio id_mun
tempfile denominators
save `denominators'

* ------------------------------------------------------------------------------
* Construct changes in jobs

* --- Denominator is 2007 manufacturing labor force
makepchjobs, indata_emp(`emp_4dig') indata_denom(`denominators') denomvar(lemim07) outfile("../data_prepped/pchjobs/lemim07")

* ------------------------------------------------------------------------------
* Construct instruments

* --- 4-digit, contemporaneous exports to US, denominator is 2003 labor force
makeipw, indata_emp(`emp_4dig') indata_chexp(`con_chexp_us_4dig') indata_denom(`denominators') denomvar(L03) indcodevar(rama) outfile("../data_prepped/ipw/con_us_l03_4dig")

* --- 4-digit, predicted exports to US, denominator is 2003 labor force [export-oriented industries]
makeipw, indata_emp(`emp_4dig_exp') indata_chexp(`prd_chexp_us_4dig') indata_denom(`denominators') denomvar(L03) indcodevar(rama) outfile("../data_prepped/ipw/prd_us_l03_4dig_exp")

* --- 4-digit, predicted exports to Mexico, denominator is 2003 labor force [domestic-oriented industries]
makeipw, indata_emp(`emp_4dig_dom') indata_chexp(`prd_chexp_mex_4dig') indata_denom(`denominators') denomvar(L03) indcodevar(rama) outfile("../data_prepped/ipw/prd_mex_l03_4dig_dom")

* --- 4-digit, predicted exports to US, denominator is 2003 labor force [upstream linkage]
makeipw, indata_emp(`emp_iocodes') indata_chexp(`prd_chexp_us_upstream') indata_denom(`denominators') denomvar(L03) indcodevar(rama) outfile("../data_prepped/ipw/prd_us_l03_upstream")

* --- 4-digit, predicted exports to US, denominator is 2003 labor force [downstream linkage]
makeipw, indata_emp(`emp_iocodes') indata_chexp(`prd_chexp_us_downstream') indata_denom(`denominators') denomvar(L03) indcodevar(rama) outfile("../data_prepped/ipw/prd_us_l03_downstream")

* --- 4-digit, contemporaneous exports to OECD, denominator is 2003 labor force
makeipw, indata_emp(`emp_4dig') indata_chexp(`con_chexp_oecd_4dig') indata_denom(`denominators') denomvar(L03) indcodevar(rama) outfile("../data_prepped/ipw/con_oecd_l03_4dig")

* --- 4-digit, predicted exports to US, denominator is 2007 EMIM labor force
makeipw, indata_emp(`emp_4dig') indata_chexp(`prd_chexp_us_4dig') indata_denom(`denominators') denomvar(lemim07) indcodevar(rama) outfile("../data_prepped/ipw/prd_us_lemim07_4dig")

* --- 6-digit, predicted exports to US, denominator is 2003 labor force
makeipw, indata_emp(`emp_6dig') indata_chexp(`prd_chexp_us_6dig') indata_denom(`denominators') denomvar(L03) indcodevar(clase) outfile("../data_prepped/ipw/prd_us_l03_6dig")
