/*

Prepares IPW and employment changes for 1998-2003.

----------------------------------------------------------------------------- */

* run programs
run "../../main/do/ipw_pchjobs_pr"

* --------- Prepare changes in exports

* these data show value of exports from China to partners, by 4-digit industry and year, from 1996-2011
use "../data_raw/comtrade1998_2011", clear
ren tradevalueus tradevalue

* keep exports to US in 1998 and 2003
keep if partnercode == 842 & inlist(period, 1998, 2003)
reshape wide tradevalue, i(rama) j(period)

* each industry's percentage of total exports in 1998
egen inishare_1998 = pc(tradevalue1998), prop

* total exports to US in 2003
egen totalvalue2003 = total(tradevalue2003)

* predict export value of each industry in 2003: total value in year 2003 x industry's share of exports in 1998
gen ptradevalue2003 = totalvalue2003 * inishare_1998

* predicted change in China exports to US from 1998 to 2003 (delta UC)
preserve
gen chexp2003 = ptradevalue2003 - tradevalue1998
keep rama chexp2003
tempfile chexp_prd_us_4dig
save `chexp_prd_us_4dig'

* contemporaneous change in China exports to US from 1998 to 2003 (delta UC)
restore
gen chexp2003 = tradevalue2003 - tradevalue1998
keep rama chexp2003
tempfile chexp_con_us_4dig
save `chexp_con_us_4dig'

* --- Predicted changes in exports from China to US (4-digit industries), upstream-linked industries and downstream-linked industries
use `chexp_prd_us_4dig', clear
gen subs = string(floor(rama / 10))
replace subs="336A" if inlist(rama, 3361, 3362, 3363)
replace subs="336B" if inlist(rama, 3364, 3365, 3366, 3369)

* merge in IO table codes
merge m:1 subs using "../data_raw/subs_usio3digit", keepusing(us_io_id3digit)
count if _merge != 3
assert(r(N) == 3)
drop if _merge != 3
collapse (sum) chexp2003, by(us_io_id3digit)
preserve

* merge with upstream weights
ren us_io_id3digit origin
merge 1:m origin using "../data_prepped/linkage_weights", assert(using match) keep(match) nogen keepusing(share_purchases destination)

* for each destination industry, multiply upstream weights by changes in exports in origin industries and sum over origin industries to get change in exports in upstream industries
collapse (sum) chexp2003 [aw=share_purchases], by(destination)
ren destination rama
tempfile prd_chexp_us_upstream
save `prd_chexp_us_upstream'

* merge with downstream weights
restore
ren us_io_id3digit destination
merge 1:m destination using "../data_prepped/linkage_weights", assert(using match) keep(match) nogen keepusing(share_sales origin)

* for each origin industry, multiply downstream weights by changes in exports in destination industries and sum over destination industries to get change in exports in downstream industries
collapse (sum) chexp2003 [aw=share_sales], by(origin)
ren origin rama
tempfile prd_chexp_us_downstream
save `prd_chexp_us_downstream'

* --- Predicted changes in exports from China to Mexico (4-digit industries)
use "../data_raw/comtrade1998_2011", clear
ren tradevalueus tradevalue
keep if partnercode == 484 & inlist(period, 1998, 2003)
reshape wide tradevalue, i(rama) j(period)

* each industry's percentage of total exports in 1998
egen inishare_1998 = pc(tradevalue1998), prop

* total exports to Mexico in 2003
egen totalvalue2003 = total(tradevalue2003)

* predict export value of each industry in 2003: total value in year t x industry's share of exports in 1998
gen ptradevalue2003 = totalvalue2003 * inishare_1998

* predicted change in China exports to Mexico from 1998
gen chexp2003 = ptradevalue2003 - tradevalue1998
keep rama chexp2003 tradevalue1998
tempfile chexp_prd_mex_4dig
save `chexp_prd_mex_4dig'

* --- Contemporaneous changes in exports from China to OECD (4-digit industries)
use "../data_raw/chinaexpOECDall_rama", clear
keep if inlist(period, 1998, 2003)
reshape wide tradevalue, i(rama) j(period)
gen chexp2003 = tradevalue2003 - tradevalue1998
keep rama chexp2003 tradevalue1998
tempfile con_chexp_oecd_4dig
save `con_chexp_oecd_4dig'

* --- Predicted changes in exports from China to US (6-digit industries)
use "../data_prepped/comtrade1998_2011_6dig", clear
ren tradevalueus tradevalue

* keep exports to US in 1998 and 2003
keep if partnercode == 842 & inlist(period, 1998, 2003)
reshape wide tradevalue, i(clase) j(period)

* each industry's percentage of total exports in 1998
replace tradevalue1998 = 0 if mi(tradevalue1998)
egen inishare_1998 = pc(tradevalue1998), prop

* predict export value of each industry in 2003: total value in year t x industry's share of exports
egen totalvalue2003 = total(tradevalue2003)
gen ptradevalue2003 = totalvalue2003 * inishare_1998

* predicted change in China exports to US from 1998 (delta UC)
gen chexp2003 = ptradevalue2003 - tradevalue1998
keep clase chexp2003 tradevalue1998
tempfile prd_chexp_us_6dig
save `prd_chexp_us_6dig'

* ------------------------------------------------------------------------------
* Prepare labor by Mexican municpality x industry

* --- 1998, 4-digit industry
use "../../main/data_raw/worker_by_type_ramamun_censo9803", clear
keep if inlist(year, 1998, 2003)
egen totemp = rowtotal(empleado obrero owner_family other_firm_worker), missing
gen id_municipio = real(string(ent, "%02.0f") + string(mun, "%03.0f"))
keep id_municipio rama year totemp
reshape wide totemp, i(id_municipio rama) j(year)
bys rama: egen natemp1998 = total(totemp1998), missing
tempfile emp_4dig
save `emp_4dig'

* --- 1998, 4-digit industry, weight by export orientation
use `emp_4dig', clear
drop natemp1998
merge 1:1 id_municipio rama using "../data_prepped/shexp98", assert(master match)
qui: summ shexp98, d
replace shexp98 = r(p50) if _merge == 1
replace totemp1998 = totemp1998 * shexp98
bys rama: egen natemp1998 = total(totemp1998)
drop shexp98 _merge
tempfile emp_4dig_exp
save `emp_4dig_exp'

* --- 1998, 4-digit industry, weight by domestic orientation
use `emp_4dig', clear
drop natemp1998
merge 1:1 id_municipio rama using "../data_prepped/shexp98", assert(master match)
qui: summ shexp98, d
replace shexp98 = r(p50) if _merge == 1
replace totemp1998 = totemp1998 * (1 - shexp98)
bys rama: egen natemp1998 = total(totemp1998)
drop shexp98 _merge
tempfile emp_4dig_dom
save `emp_4dig_dom'

* --- 1998 using IO codes for linkage IPW
use `emp_4dig', clear
gen subs = string(floor(rama / 10))
replace subs="336A" if inlist(rama, 3361, 3362, 3363)
replace subs="336B" if inlist(rama, 3364, 3365, 3366, 3369)
merge m:1 subs using "../data_raw/subs_usio3digit", assert(using match) keep(match) nogen keepusing(us_io_id3digit)
drop rama subs
sort id_mun us_io_id3digit
foreach v of var totemp1998 natemp1998 {
    by id_mun us_io_id3digit: egen total_`v' = total(`v'), missing
    replace `v' = total_`v'
    drop total_`v'
}
duplicates drop
ren us_io_id3digit rama
tempfile emp_iocodes
save `emp_iocodes'

* --- NOTE: 1998, 6-digit, is already prepared by prepemp98_6dig.do

* ------------------------------------------------------------------------------
* Construct percent changes in jobs

* create municipal employment
use `emp_4dig', clear
bys id_municipio: egen mun_totemp1998 = total(totemp1998), missing
bys id_municipio: egen mun_totemp2003 = total(totemp2003), missing
keep id_municipio mun_totemp*
duplicates drop

* merge with labor in 1998
ren id_municipio id_mun
merge 1:1 id_mun using "../../main/data_prepped/labor98", keep(match) nogen keepusing(lman98)

* --- Create percent changes in jobs (denominator is 1998 manuf employment)
gen pchjobs2003 = (mun_totemp2003 - mun_totemp1998) / lman98
drop if mi(pchjobs2003)
keep id_mun pchjobs2003
save "../data_prepped/pchjobs/9803/lman98", replace

* ------------------------------------------------------------------------------
* Construct instruments

* --- 4-digit, contemporaneous exports to US, denominator is 1998 labor force
makeipw98, indata_emp(`emp_4dig') indata_chexp(`chexp_con_us_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9803/con_us_l98_4dig") endyr(2003)

* --- 4-digit, predicted exports to US, denominator is 1998 labor force [export-oriented industries]
makeipw98, indata_emp(`emp_4dig_exp') indata_chexp(`chexp_prd_us_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9803/prd_us_l98_4dig_exp") endyr(2003)

* --- 4-digit, predicted exports to Mexico, denominator is 1998 labor force [domestic-oriented industries]
makeipw98, indata_emp(`emp_4dig_dom') indata_chexp(`chexp_prd_mex_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9803/prd_mex_l98_4dig_dom") endyr(2003)

* --- 4-digit, predicted exports to US, denominator is 1998 labor force [downstream linkage]
makeipw98, indata_emp(`emp_iocodes') indata_chexp(`prd_chexp_us_downstream') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9803/prd_us_l98_downstream") endyr(2003)

* --- 4-digit, predicted exports to US, denominator is 1998 labor force [upstream linkage]
makeipw98, indata_emp(`emp_iocodes') indata_chexp(`prd_chexp_us_upstream') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9803/prd_us_l98_upstream") endyr(2003)

* --- 4-digit, contemporaneous exports to OECD, denominator is 1998 labor force
makeipw98, indata_emp(`emp_4dig') indata_chexp(`con_chexp_oecd_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9803/con_oecd_l98_4dig") endyr(2003)

* --- 6-digit, predicted exports to US, denominator is 1998 labor force
makeipw98, indata_emp("../data_prepped/emp98_6dig") indata_chexp(`prd_chexp_us_6dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(clase) outfile("../data_prepped/ipw/9803/prd_us_l98_6dig") endyr(2003)

* --- 4-digit, predicted exports to US, denom is 1998 manuf labor force
makeipw98, indata_emp(`emp_4dig') indata_chexp(`chexp_prd_us_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(lman98) indcodevar(rama) outfile("../data_prepped/ipw/9803/prd_us_lman98_4dig") endyr(2003)
