/*

Prepares IPW and employment changes for 1998-2013.

----------------------------------------------------------------------------- */

* --------- Prepare changes in exports

* --- Construct changes in exports to US (predicted shares)

* keep exports to US in 1998
use "../data_raw/comtrade1998_2011", clear
keep if partnercode == 842 & period == 1998
ren tradevalueus tradevalue1998
keep rama tradevalue1998

* merge 1998 and 2013
merge 1:1 rama using "../../main/data_prepped/comtrade_us13"
ren tradevalueus tradevalue2013
assert(mi(rama) | inlist(rama, 1112, 1114, 1121, 1123)) if _merge != 3
drop _merge
preserve

* each industry's percentage of total exports in 1998
egen inishare_1998 = pc(tradevalue1998), prop

* predict export value of each industry in 2013: total value in year 2013 x industry's share of exports in 1998
egen totalvalue2013 = total(tradevalue2013)
gen ptradevalue2013 = totalvalue2013 * inishare_1998

* predicted change in China exports to US from 1998 to 2013 (delta UC)
gen chexp2013 = ptradevalue2013 - tradevalue1998
keep rama chexp2013
tempfile prd_chexp_us_4dig
save `prd_chexp_us_4dig'

* --- Construct changes in exports to US (contemporaneous shares)
restore
gen chexp2013 = tradevalue2013 - tradevalue1998
keep rama chexp2013
tempfile con_chexp_us_4dig
save `con_chexp_us_4dig'

* --- Construct changes in exports to Mexico (predicted shares)

* keep exports to Mexico in 1998
use "../data_raw/comtrade1998_2011", clear
keep if partnercode == 484 & period == 1998
ren tradevalueus tradevalue1998
keep rama tradevalue1998

* merge 1998 and 2013
merge 1:1 rama using "../data_prepped/comtrade_mex13"
ren tradevalueus tradevalue2013
assert(mi(rama)) if _merge == 1
drop if (_merge == 2 & inrange(rama, 1000, 2999)) | _merge == 1
recode tradevalue1998 (. = 0) if _merge == 2
preserve

* each industry's percentage of total exports in 1998
egen inishare_1998 = pc(tradevalue1998), prop

* predict export value of each industry in 2013: total value in year 2013 x industry's share of exports in 1998
egen totalvalue2013 = total(tradevalue2013)
gen ptradevalue2013 = totalvalue2013 * inishare_1998

* predicted change in China exports to Mexico from 1998 to 2013 (delta UC)
gen chexp2013 = ptradevalue2013 - tradevalue1998
keep rama chexp2013
tempfile prd_chexp_mex_4dig
save `prd_chexp_mex_4dig'

* --- Construct changes in exports to US (contemporaneous shares)
restore
gen chexp2013 = tradevalue2013 - tradevalue1998
keep rama chexp2013
tempfile con_chexp_mex_4dig
save `con_chexp_mex_4dig'

* --- Predicted changes in exports from China to US (4-digit industries), upstream-linked industries and downstream-linked industries
foreach v in prd con {
    use ``v'_chexp_us_4dig', clear
    gen subs = string(floor(rama / 10))
    replace subs="336A" if inlist(rama, 3361, 3362, 3363)
    replace subs="336B" if inlist(rama, 3364, 3365, 3366, 3369)

    * merge in IO table codes
    merge m:1 subs using "../data_raw/subs_usio3digit", keepusing(us_io_id3digit)
    count if _merge != 3
    assert(r(N) == 3)
    drop if _merge != 3
    collapse (sum) chexp*, by(us_io_id3digit)
    preserve

    * merge with upstream weights
    ren us_io_id3digit origin
    merge 1:m origin using "../data_prepped/linkage_weights", assert(using match) keep(match) nogen keepusing(share_purchases destination)

    * for each destination industry, multiply upstream weights by changes in exports in origin industries and sum over origin industries to get change in exports in upstream industries
    collapse (sum) chexp* [aw=share_purchases], by(destination)
    ren destination rama
    tempfile `v'_chexp_us_upstream
    save ``v'_chexp_us_upstream'

    * merge with downstream weights
    restore
    ren us_io_id3digit destination
    merge 1:m destination using "../data_prepped/linkage_weights", assert(using match) keep(match) nogen keepusing(share_sales origin)

    * for each origin industry, multiply downstream weights by changes in exports in destination industries and sum over destination industries to get change in exports in downstream industries
    collapse (sum) chexp* [aw=share_sales], by(origin)
    ren origin rama
    tempfile `v'_chexp_us_downstream
    save ``v'_chexp_us_downstream'
}

* --- Prepare contemporaneous changes to exports in OECD countries

* China to OECD in 1998
use "../data_raw/chinaexpOECDall_rama", clear
keep if period == 1998
drop period
ren tradevalue tradevalue1998
tempfile trade98_oecd
save `trade98_oecd'

* China to OECD in 2013
use "../data_prepped/comtrade_oecd13", clear
ren tradevalueus tradevalue2013
merge 1:1 rama using `trade98_oecd', assert(using match)
assert(tradevalue1998 == 0) if _merge == 2
drop if _merge == 2
gen chexp2013 = tradevalue2013 - tradevalue1998
keep rama chexp2013 tradevalue1998
tempfile con_chexp_oecd_4dig
save `con_chexp_oecd_4dig'

* --- Construct changes in exports (predicted shares), 6-digit

* keep exports to US in 1998
use "../data_prepped/comtrade1998_2011_6dig", clear
keep if partnercode == 842 & period == 1998
ren tradevalueus tradevalue1998
keep clase tradevalue1998

* merge 1998 and 2013
merge 1:1 clase using "../../main/data_prepped/comtrade_us13_6dig", keep(match) nogen
ren tradevalueus tradevalue2013
preserve

* each industry's percentage of total exports in 1998
egen inishare_1998 = pc(tradevalue1998), prop

* predict export value of each industry in 2013: total value in year 2013 x industry's share of exports in 1998
egen totalvalue2013 = total(tradevalue2013)
gen ptradevalue2013 = totalvalue2013 * inishare_1998

* predicted change in China exports to US from 1998 to 2013 (delta UC)
gen chexp2013 = ptradevalue2013 - tradevalue1998
keep clase chexp2013 tradevalue1998
tempfile prd_chexp_us_6dig
save `prd_chexp_us_6dig'

* --- Construct changes in exports (contemporaneous shares), 6-digit
restore
gen chexp2013 = tradevalue2013 - tradevalue1998
keep clase chexp2013 tradevalue1998
tempfile con_chexp_us_6dig
save `con_chexp_us_6dig'

* ------------------------------------------------------------------------------
* Prepare labor by Mexican municipality x industry

* --- Prepare 1998
use "../../main/data_raw/worker_by_type_ramamun_censo9803", clear
keep if year == 1998
egen totemp = rowtotal(empleado obrero owner_family other_firm_worker)
gen id_municipio = real(string(ent, "%02.0f") + string(mun, "%03.0f"))
ren totemp totemp1998
keep id_municipio rama totemp1998
bys rama: egen natemp1998 = total(totemp1998)
tempfile emp1998
save `emp1998'

* --- Prepare 2013
use "../../main/data_raw/Censo_manuf_emp13", clear
keep id_municipio Censo_2014_manuf
duplicates drop
ren Censo_2014_manuf mun_totemp2013
tempfile emp2013
save `emp2013'

* --- 1998, 4-digit industry, weight by export orientation
use `emp1998', clear
drop natemp1998
merge 1:1 id_municipio rama using "../data_prepped/shexp98", assert(master match)
qui: summ shexp98, d
replace shexp98 = r(p50) if _merge == 1
replace totemp = totemp * shexp98
bys rama: egen natemp1998 = total(totemp1998)
drop shexp98 _merge
tempfile emp1998_exp
save `emp1998_exp'

* --- 1998, 4-digit industry, weight by domestic orientation
use `emp1998', clear
drop natemp1998
merge 1:1 id_municipio rama using "../data_prepped/shexp98", assert(master match)
qui: summ shexp98, d
replace shexp98 = r(p50) if _merge == 1
replace totemp = totemp * (1 - shexp98)
bys rama: egen natemp1998 = total(totemp1998)
drop shexp98 _merge
tempfile emp1998_dom
save `emp1998_dom'

* --- 1998 using IO codes for linkage IPW
use `emp1998', clear

* merge with IO table codes
gen subs = string(floor(rama / 10))
replace subs = "336A" if inlist(rama, 3361, 3362, 3363)
replace subs = "336B" if inlist(rama, 3364, 3365, 3366, 3369)
merge m:1 subs using "../data_raw/subs_usio3digit", assert(using match) keep(match) nogen keepusing(us_io_id3digit)
drop rama subs
sort id_mun us_io_id3digit
foreach v of var totemp1998 natemp1998 {
    by id_mun us_io_id3digit: egen total_`v' = total(`v'), missing
    replace `v' = total_`v'
    drop total_`v'
}
duplicates drop
ren us_io_id3digit rama
tempfile emp1998_iocodes
save `emp1998_iocodes'

* --- NOTE: 1998, 6-digit, is already prepared by prepemp98_6dig.do

* ------------------------------------------------------------------------------
* Construct percent changes in jobs

* create municipal employment in 1998
use `emp1998', clear
bys id_municipio: egen mun_totemp1998 = total(totemp1998), missing
keep id_municipio mun_totemp
duplicates drop

* merge with municipal employment in 2013
merge 1:1 id_municipio using `emp2013', nogen

* merge with labor in 1998
ren id_municipio id_mun
merge 1:1 id_mun using "../../main/data_prepped/labor98", assert(master match) keep(match) nogen keepusing(lman98)

* --- Create percent changes in jobs (denominator is 1998 manuf employment)
gen pchjobs2013 = (mun_totemp2013 - mun_totemp1998) / lman98
drop if mi(pchjobs2013)
keep id_mun pchjobs2013 mun_totemp2013 mun_totemp1998
save "../data_prepped/pchjobs/9813/lman98", replace

* ------------------------------------------------------------------------------
* Construct IPW

* --- 4-digit, contemporaneous exports to US, denominator is 1998 labor force
makeipw98, indata_emp(`emp1998') indata_chexp(`con_chexp_us_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9813/con_us_l98_4dig") endyr(2013)

* --- 4-digit, predicted exports to US, denominator is 1998 labor force [export-oriented]
makeipw98, indata_emp(`emp1998_exp') indata_chexp(`prd_chexp_us_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9813/prd_us_l98_4dig_exp") endyr(2013)

* --- 4-digit, predicted exports to Mexico, denominator is 1998 labor force [domestic-oriented]
makeipw98, indata_emp(`emp1998_dom') indata_chexp(`prd_chexp_mex_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9813/prd_mex_l98_4dig_dom") endyr(2013)

* --- 4-digit, predicted exports to US, denominator is 1998 labor force [upstream linkage]
makeipw98, indata_emp(`emp1998_iocodes') indata_chexp(`prd_chexp_us_upstream') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9813/prd_us_l98_upstream") endyr(2013)

* --- 4-digit, predicted exports to US, denominator is 1998 labor force [downstream linkage]
makeipw98, indata_emp(`emp1998_iocodes') indata_chexp(`prd_chexp_us_downstream') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9813/prd_us_l98_downstream") endyr(2013)

* --- 4-digit, contemporaneous exports to OECD, denominator is 1998 labor force
makeipw98, indata_emp(`emp1998') indata_chexp(`con_chexp_oecd_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9813/con_oecd_l98_4dig") endyr(2013)

* --- 6-digit, predicted exports to US, denominator is 1998 labor force
makeipw98, indata_emp("../data_prepped/emp98_6dig") indata_chexp(`prd_chexp_us_6dig') indata_denom("../../main/data_prepped/labor98") denomvar(labor98) indcodevar(clase) outfile("../data_prepped/ipw/9813/prd_us_l98_6dig") endyr(2013)

* --- 4-digit, predicted exports to US, denominator is 1998 manuf labor force
makeipw98, indata_emp(`emp1998') indata_chexp(`prd_chexp_us_4dig') indata_denom("../../main/data_prepped/labor98") denomvar(lman98) indcodevar(rama) outfile("../data_prepped/ipw/9813/prd_us_lman98_4dig") endyr(2013)
