/*

Programs to run analysis and produce tables for a given specification.

----------------------------------------------------------------------------- */

* --- Load programs from main maketables.do
run "../../main/do/maketables"

* ------------------------------------------------------------------------------
* Makes one table with PAN Gain outcome

cap program drop maketables_pan
program maketables_pan
    syntax, ///
        ipwdatalist(string asis) /// dataset with ipws
        pchjobsdata(string) /// dataset with pchjobs
        wtvar(string) /// what variable to weight by
        outfldr(string) /// output folder
        [convars(string) /// control variables
        nostd] /// do not standardize pchjobs

    * --- Make outfldr if it does not exist
    confirmdir "`outfldr'"
    if real(r(confirmdir)) mkdir "`outfldr'"

    * --- Prepare 2007-10/11 data
    tempfile mundata_main
    prepdata_main, ipwdatalist(`ipwdatalist') pchjobsdata("`pchjobsdata'") wtvar(`wtvar') data(`mundata_main') `std'

    * --------------------------------------------------------------------------
    * Regressions

    * column 1 - PAN gain (full sample)
    ivregout [aw=`wtvar'], outvar(pan_gain0710) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars') store(t1) addrows(Sample, All)

    * column 2 - PAN gain (no DTO sample)
    ivregout [aw=`wtvar'] if cartel == 0, outvar(pan_gain0710) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars') merge(t1) addrows(Sample, No DTO)

    * column 3 - PAN gain (any DTO sample)
    ivregout [aw=`wtvar'] if cartel == 1, outvar(pan_gain0710) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars') merge(t1) addrows(Sample, Any DTO)

    * column 4 - PAN gain (major DTO sample)
    ivregout [aw=`wtvar'] if C_major == 1, outvar(pan_gain0710) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars') merge(t1) addrows(Sample, Major DTO)

    * produce table
    outreg using "`outfldr'/t1.tex", replay(t1) replace tex plain fragment nocenter ctitles("", "PAN Gain (2007-10)", "", "PAN Gain (2007-10)" \ "", (1), (2), (3), (4)) spacebef(101{0}) spaceaft(01{0}1) multicol(1, 2, 2; 1, 4, 2)
end

* ------------------------------------------------------------------------------
* Makes one table for a 1998-based dataset, varying controls

cap program drop makeonetable_varycon98
program makeonetable_varycon98
    syntax [if] [aw], ///
        outvar(string) /// outcome variable
        outfldr(string) /// output folder
        outfilename(string) /// output tex file name
        endyr(int) /// ending year
        [samplestr(string)] /// string label to specify sample

    * --------------------------------------------------------------------------
    * Make table

    * manufacturing share only
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw`endyr'_num*) endvar(pchjobs`endyr') convars(sharemanuf98) store(t) addrows(Sample, `samplestr')

    * add state FE
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw`endyr'_num*) endvar(pchjobs`endyr') convars(sharemanuf98 i.ent) merge(t) addrows(Sample, `samplestr')

    * add baseline outcomes
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw`endyr'_num*) endvar(pchjobs`endyr') convars(sharemanuf98 i.ent homrate_inegi_1998 logValueDom_total1998 logValueFor_total1998) merge(t) addrows(Sample, `samplestr')

    * add geographic controls
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw`endyr'_num*) endvar(pchjobs`endyr') convars(sharemanuf98 i.ent homrate_inegi_1998 logValueDom_total1998 logValueFor_total1998 logC_distUS elev slope temp precip) merge(t) addrows(Sample, `samplestr')

    * add economic controls
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw`endyr'_num*) endvar(pchjobs`endyr') convars(sharemanuf98 i.ent homrate_inegi_1998 logValueDom_total1998 logValueFor_total1998 logC_distUS elev slope temp precip lincearn90 yrschool90) merge(t) addrows(Sample, `samplestr')

    * add political controls
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw`endyr'_num*) endvar(pchjobs`endyr') convars(sharemanuf98 i.ent homrate_inegi_1998 logValueDom_total1998 logValueFor_total1998 logC_distUS elev slope temp precip lincearn90 yrschool90 pri_power1998 pan_power1998 prd_power1998 elecdummy) merge(t) addrows(Sample, `samplestr')

    * add political controls
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw`endyr'_num*) endvar(pchjobs`endyr') convars(sharemanuf98 homrate_inegi_1998 logValueDom_total1998 logValueFor_total1998 logC_distUS elev slope temp precip lincearn90 yrschool90 pri_power1998 pan_power1998 prd_power1998 elecdummy) merge(t) addrows(Sample, `samplestr')

    * produce table
    outreg using "`outfldr'/`outfilename'", replay(t) replace tex plain fragment nocenter ctitles("", "Only", "Add", "Add", "Add", "Add", "Add", "All" \ "", "Manuf.", "State", "Baseline", "Geographic", "Economic", "Political", "Except" \ "", "Share", "FE", "Outcomes", "Controls", "Controls", "Controls", "State FE" \ "", (1), (2), (3), (4), (5), (6), (7)) spacebef(10001{0}) spaceaft(0001{0}1)
end

* ------------------------------------------------------------------------------
* Makes one table with main result, varying controls

cap program drop makeonetable_varycon
program makeonetable_varycon
    syntax [if] [aw], ///
        outvar(string) /// outcome variable
        outfldr(string) /// output folder
        outfilename(string) /// output tex file name
        [samplestr(string)] /// string label to specify sample

    * --------------------------------------------------------------------------
    * Make table

    * manufacturing share only
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(share0) store(t_1) addrows(Sample, `samplestr')

    * add state FE
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(share0 i.ent) merge(t_1) addrows(Sample, `samplestr')

    * add baseline outcomes
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(share0 i.ent logValueDom_total2007 logValueFor_total2007 homrate_pres_2007) merge(t_1) addrows(Sample, `samplestr')

    * add geographic controls
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(share0 i.ent logValueDom_total2007 logValueFor_total2007 homrate_pres_2007 logC_distUS elev slope temp precip) merge(t_1) addrows(Sample, `samplestr')

    * add economic controls
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(share0 i.ent logValueDom_total2007 logValueFor_total2007 homrate_pres_2007 logC_distUS elev slope temp precip C_marginal C_infantMort C_ed) store(t_2) addrows(Sample, `samplestr')

    * add political controls
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(share0 i.ent logValueDom_total2007 logValueFor_total2007 homrate_pres_2007 logC_distUS elev slope temp precip C_marginal C_infantMort C_ed pri_power2007 pan_power2007 prd_power2007 elecdummy) merge(t_2) addrows(Sample, `samplestr')

    * add dto controls
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(share0 i.ent logValueDom_total2007 logValueFor_total2007 homrate_pres_2007 logC_distUS elev slope temp precip C_marginal C_infantMort C_ed pri_power2007 pan_power2007 prd_power2007 elecdummy C_major cartel rival) merge(t_2) addrows(Sample, `samplestr')

    * version with everything except state fe
    ivregout [`weight'`exp'] `if', outvar(`outvar') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(share0 logValueDom_total2007 logValueFor_total2007 homrate_pres_2007 logC_distUS elev slope temp precip C_marginal C_infantMort C_ed pri_power2007 pan_power2007 prd_power2007 elecdummy C_major cartel rival) merge(t_2) addrows(Sample, `samplestr')

    * produce table
    outreg using "`outfldr'/`outfilename'.tex", replay(t_1) merge(t_2) replace tex plain fragment nocenter ctitles("", "Only", "Add", "Add", "Add", "Add", "Add", "Add", "All" \ "", "Manuf.", "State", "Baseline", "Geographic", "Economic", "Political", "DTO", "Except" \ "", "Share", "FE", "Outcomes", "Controls", "Controls", "Controls", "Controls", "State FE" \ "", (1), (2), (3), (4), (5), (6), (7), (8)) spacebef(10001{0}) spaceaft(0001{0}1)
end

* ------------------------------------------------------------------------------
* Make all tables with main results, varying controls

cap program drop maketables_varycon
program maketables_varycon
    syntax, ///
        ipwdatalist_main(string) /// main dataset with ipws
        pchjobsdata_main(string) /// main dataset with pchjobs
        wtvar_main(string) /// main variable to weight by
        ipwdatalist98(string) /// dataset with ipws for 1998 analyses
        pchjobsdata98(string) /// dataset with pchjobs for 1998 analyses
        wtvar98(string) /// variable to weight by for 1998 analyses
        outfldr(string) /// output folder

    * --- Prepare main (2007-2010/11) data
    tempfile mundata_main
    prepdata_main, ipwdatalist(`ipwdatalist_main') pchjobsdata("`pchjobsdata_main'") wtvar(`wtvar_main') data(`mundata_main')

    * --- Prepare 1998-2003 data
    tempfile mundata_9803
    prepdata_9803, ipwdatalist(`ipwdatalist98') pchjobsdata("`pchjobsdata98'") wtvar(`wtvar98') data(`mundata_9803') ipwlabels(`ipwlabels')

    * --- Prepare 1998-2013
    tempfile mundata_9813
    prepdata_9813, ipwdatalist(`ipwdatalist98') pchjobsdata("`pchjobsdata98'") wtvar(`wtvar98') data(`mundata_9813') ipwlabels(`ipwlabels')

    * --- Make outfldr if it does not exist
    confirmdir "`outfldr'"
    if real(r(confirmdir)) mkdir "`outfldr'"

    * --------------------------------------------------------------------------
    * Make tables

    * all homicides, 1998-2013
    use `mundata_9813', clear
    makeonetable_varycon98 [aw=`wtvar98'], outvar(homdiff_9813) outfldr("`outfldr'") outfilename("hom9813") endyr(2013) samplestr("All")

    * all homicides, 1998-2003
    use `mundata_9803', clear
    makeonetable_varycon98 [aw=`wtvar98'], outvar(homdiff_9803) outfldr("`outfldr'") outfilename("hom9803") endyr(2003) samplestr("All")

    * drug-related homicides, full sample
    use `mundata_main', clear
    makeonetable_varycon [aw=`wtvar_main'], outvar(homdiff_rate_long3) outfldr("`outfldr'") outfilename("hom_full") samplestr("All")

    * log foreign confiscations, full sample
    makeonetable_varycon [aw=`wtvar_main'], outvar(logValueFor_total3diff) outfldr("`outfldr'") outfilename("cocconf_full") samplestr("All")

    * log domestic confiscations, full sample
    makeonetable_varycon [aw=`wtvar_main'], outvar(logValueDom_total3diff) outfldr("`outfldr'") outfilename("ncocconf_full") samplestr("All")

    * drug-related homicides, any dto sample
    makeonetable_varycon [aw=`wtvar_main'] if cartel, outvar(homdiff_rate_long3) outfldr("`outfldr'") outfilename("hom_any") samplestr("Any DTO")

    * log foreign confiscations, any dto sample
    makeonetable_varycon [aw=`wtvar_main'] if cartel, outvar(logValueFor_total3diff) outfldr("`outfldr'") outfilename("cocconf_any") samplestr("Any DTO")

    * log domestic confiscations, any dto sample
    makeonetable_varycon [aw=`wtvar_main'] if cartel, outvar(logValueDom_total3diff) outfldr("`outfldr'") outfilename("ncocconf_any") samplestr("Any DTO")

    * drug-related homicides, major dto sample
    makeonetable_varycon [aw=`wtvar_main'] if C_major, outvar(homdiff_rate_long3) outfldr("`outfldr'") outfilename("hom_major") samplestr("Maj DTO")

    * log foreign confiscations, major dto sample
    makeonetable_varycon [aw=`wtvar_main'] if C_major, outvar(logValueFor_total3diff) outfldr("`outfldr'") outfilename("cocconf_major") samplestr("Maj DTO")

    * log domestic confiscations, major dto sample
    makeonetable_varycon [aw=`wtvar_main'] if C_major, outvar(logValueDom_total3diff) outfldr("`outfldr'") outfilename("ncocconf_major") samplestr("Maj DTO")
end
