/*

Runs all code to produce appendixes.

----------------------------------------------------------------------------- */

* load programs
run "../../main/do/frmttable.ado"
run maketables
run randinf

* load control lists
include "../../main/do/conlist"

* make directories for output
do "../../main/do/mkdirs"

* --------- Data prep

* prepare industry linkage weights for export-oriented and domestic-oriented IPWs
do prep_linkage_weights

* create appendix versions of IPW and pchjobs measures at municipality level
do ipw_pchjobs

* aggregate appendix versions of IPW and pchjobs measures to state level
do "../../main/do/ipw_pchjobs_state"

* prepare share of output exported in 1998
do prep_shexp98

* prepare appendix versions of 1998-2003 ipws and pchjobs
do ipw_pchjobs_9803

* prepare appendix versions of 1998-2013 ipws and pchjobs
do ipw_pchjobs_9813

* copy main data, ipws, and pchjobs from main folder into appendix folder
do copydata

* ------------------------------------------------------------------------------
* Appendixes

* --- Appendix A: Vary controls
maketables_varycon, ipwdatalist_main(prd_us_l03_4dig) pchjobsdata_main(l03) wtvar_main(L03) ipwdatalist98(prd_us_l98_4dig) pchjobsdata98(l98) wtvar98(labor98) outfldr("../results/tables/nostars/varycontrols")

* --- Appendix B: PAN gain outcome
maketables_pan, ipwdatalist(prd_us_l03_4dig) pchjobsdata(l03) wtvar(L03) outfldr("../results/tables/nostars/pan") convars(`convars_main')

* --- Appendix C: Contemporaneous exports to US ICW
maketables_main, outfldr("../results/tables/nostars/contemp") convars_main(`convars_main') convars_pp_core(`convars_pp_core') convars_pp_prefix(`convars_pp_prefix') convars98(`convars98') ipwdatalist_main(con_us_l03_4dig) pchjobsdata_main(l03) wtvar_main(L03) ipwdatalist98(con_us_l98_4dig) pchjobsdata98(l98) wtvar98(labor98)

* --- Appendix D: Export-oriented and domestic-oriented ICWs
maketables_main, outfldr("../results/tables/nostars/expdom") convars_main(`convars_main') convars_pp_core(`convars_pp_core') convars_pp_prefix(`convars_pp_prefix') convars98(`convars98') ipwdatalist_main("prd_us_l03_4dig_exp" "prd_mex_l03_4dig_dom") pchjobsdata_main(l03) wtvar_main(L03) ipwdatalist98("prd_us_l98_4dig_exp" "prd_mex_l98_4dig_dom") pchjobsdata98(l98) wtvar98(labor98)  ipwlabels("Export-Oriented" "Domestic-Oriented")

* --- Appendix E: Predicted exports to US ICW and linkage ICW
maketables_main, outfldr("../results/tables/nostars/linkage") convars_main(`convars_main') convars_pp_core(`convars_pp_core') convars_pp_prefix(`convars_pp_prefix') convars98(`convars98') ipwdatalist_main("prd_us_l03_4dig" "prd_us_l03_upstream" "prd_us_l03_downstream") pchjobsdata_main(l03) wtvar_main(L03) ipwdatalist98("prd_us_l98_4dig" "prd_us_l98_upstream" "prd_us_l98_downstream") pchjobsdata98(l98) wtvar98(labor98) ipwlabels("Main" "Upstream" "Downstream")

* --- Appendix F: Contemporaneous exports to OECD ICW
maketables_main, outfldr("../results/tables/nostars/con_oecd") convars_main(`convars_main') convars_pp_core(`convars_pp_core') convars_pp_prefix(`convars_pp_prefix') convars98(`convars98') ipwdatalist_main(con_oecd_l03_4dig) pchjobsdata_main(l03) wtvar_main(L03) ipwdatalist98(con_oecd_l98_4dig) pchjobsdata98(l98) wtvar98(labor98)

* --- Appendix G: 6-Digit Data
maketables_main, outfldr("../results/tables/nostars/sixdig") convars_main(`convars_main') convars_pp_core(`convars_pp_core') convars_pp_prefix(`convars_pp_prefix') convars98(`convars98') ipwdatalist_main(prd_us_l03_6dig) pchjobsdata_main(l03) wtvar_main(L03) ipwdatalist98(prd_us_l98_6dig) pchjobsdata98(l98) wtvar98(labor98)

* --- Appendix H: Manufacturing Labor Force as Denominator
maketables_main, outfldr("../results/tables/nostars/manufwt") convars_main(`convars_main') convars_pp_core(`convars_pp_core') convars_pp_prefix(`convars_pp_prefix') convars98(`convars98') ipwdatalist_main(prd_us_lemim07_4dig) pchjobsdata_main(lemim07) wtvar_main(lemim07) ipwdatalist98(prd_us_lman98_4dig) pchjobsdata98(lman98) wtvar98(lman98)

* --- Appendix I: Main Randomization Inference

* NOTE: takes ~24 minutes to run
randinf_all, outfldr_plot("../results/randinf_plots") outfldr_tab("../results/tables/nostars/pvaltab") convars_main(`convars_main') convars98(`convars98') ipwdatalist_main(prd_us_l03_4dig) pchjobsdata_main(l03) wtvar_main(L03) ipwdatalist98(prd_us_l98_4dig) pchjobsdata98(l98) wtvar98(labor98)

* ------------------------------------------------------------------------------
* Compile tables

* --- NOTE: works only in Windows
loc pwd = c(pwd)
shell(cd "../results" & pdflatex appendix_nostars.tex --quiet & pdflatex appendix_nostars.tex --quiet & echo Successfully compiled results/appendix_nostars.pdf & timeout 2)
cd "`pwd'"
