/*

Prepares elections data.

----------------------------------------------------------------------------- */

* --- Prepare elections data from 1970-2009 source
use "../data_raw/Elecciones_Municipales_1993-2009.dta", clear
ren A*o year
keep if year >= 1993
ren Part_1 winner

* keep only one observation per election - the observation that defines the winning party or coalition
qui: duplicates r id_municipio year
loc nunique = r(unique_value)
qui: duplicates r id_municipio year if !mi(winner)
assert(r(unique_value) == `nunique' & r(unique_value) == r(N))
keep if !mi(winner)

* variables that indicate whether PRI, PAN, or PRD was in winning coalition
foreach party in pri pan prd {
    gen `party'_win = regexm(winner, upper("`party'"))
}
replace pan_win = 0 if inlist(winner, "PRI_PANAL", "PRI_PVEM_PANAL_VIA_V_C")
gen other_win = !pri_win & !pan_win & !prd_win

* reshape to wide
keep id_municipio year *_win
reshape wide *_win, i(id_municipio) j(year)
tempfile elections_src70_09
save `elections_src70_09'

* --- Prepare elections data from 2009-13 source
use  "../data_raw/Elec09_10.dta", clear
gen year = year(YMD_Elec)
keep if inrange(year, 2009, 2011)

* reshape to wide
keep id_municipio year *_win
reshape wide *_win, i(id_municipio) j(year)

* --- Merge datasets (only update the 2009 values if missing in the 2009-13 source but present in the 1970-2009 source)
merge 1:1 id_municipio using `elections_src70_09', nogen update

* --- Merge in inauguration year for 2007 and 2010 elections

* reshape to municipality x year level
reshape long pri_win pan_win prd_win other_win, i(id_municipio) j(year)
drop if mi(pri_win)

* merge with inauguration years in 2007 and 2010
ren year elecyr
gen id_estado = floor(id_municipio / 1000)
merge m:1 id_estado elecyr using "../data_raw/yrinaug0710", keepusing(inaugyr) keep(master match)

* check that all the 2007 and 2010 elections merged with the inauguration data
assert(_merge == 3) if inlist(elecyr, 2007, 2010)

* for years other than 2007 and 2010, the inauguration year may not have been the same as the election year, but for our purposes it doesn't matter so we just set the inauguration year to be the election year
replace inaugyr = elecyr if _merge == 1
drop _merge id_estado elecyr

* indicate who was in power in 2010
preserve
drop if inaugyr > 2010 | inaugyr < 2003
bys id_municipio (inaugyr): keep if _n == _N
drop inaugyr
ren *_win *_power2010
tempfile power2010
save `power2010'

* indicate who was in power in 2007
restore, preserve
drop if inaugyr > 2007 | inaugyr < 2003
bys id_municipio (inaugyr): keep if _n == _N
drop inaugyr
ren *_win *_power2007
tempfile power2007
save `power2007'

* indicate who was in power in 1998
restore
drop if inaugyr > 1998
bys id_municipio (inaugyr): keep if _n == _N
drop inaugyr
ren *_win *_power1998
compress
save "../data_prepped/elections98", replace

* create change variables 2007-10
use `power2007'
merge 1:1 id_municipio using `power2010', assert(using match)
foreach party in pri pan prd other {
    gen `party'_gain0710 = `party'_power2010 == 1 if `party'_power2007 == 0
}
egen anychange0710 = rowtotal(*_gain0710) if _merge == 3
replace anychange0710 = 1 if anychange0710 == 2
assert(inlist(anychange0710, 0, 1)) if !mi(anychange0710)
drop _merge

* save
compress
save "../data_prepped/elections0710", replace
