/*

Creates opinion changes from 2005-2012 using state-level ENCUP data.

----------------------------------------------------------------------------- */

* --- Prepare 2005
use "../data_raw/Base_3ra_ENCUP", clear

* drop rural muns
gen id_municipio = (cve_ent * 1000) + cve_mun
merge m:1 id_municipio using "../../main/data_raw/mun_characteristics", assert(using match) keep(match) nogen keepusing(tipo_mun)
drop if tipo_mun == "RU"

* construct political outcomes (1, 2, and 3 are yes, somewhat, no [or analagous] and 4, 8, and 9 are "OTRO" "ns" and "nc" [don't know what these mean])
ren p17 pol_contribute
ren p24 opportunity
ren p34a status_dem
foreach v of var pol_contribute opportunity status_dem {
    assert(inlist(`v', 1, 2, 3, 4, 8, 9))
    replace `v' = . if inlist(`v', 4, 8, 9)
}

* reverse coding so that 1 means disagree, 2 is agree somewhat, 3 is agree
foreach v of var pol_contribute opportunity status_dem {
    recode `v' (1=3) (3=1)
}

* average within states
collapse (mean) pol_contribute opportunity status_dem, by(cve_ent)
ren * *_05
ren cve_ent_05 cve_ent
tempfile encup05
save `encup05'

* --- Prepare 2012
use "../data_raw/Base_Quinta ENCUP_2012", clear
ren edo cve_ent

* drop rural muns
gen id_municipio = (cve_ent * 1000) + mun
merge m:1 id_municipio using "../../main/data_raw/mun_characteristics", assert(using match) keep(match) nogen keepusing(tipo_mun)
drop if tipo_mun == "RU"

* construct political outcomes (1, 2, and 3 are yes, somewhat, no [or analagous] and 98 and 99 are "No s[]" and "No contesta" [don't know what these mean])
ren p38 pol_contribute
ren p55 opportunity
ren p15 status_dem
foreach v of var pol_contribute opportunity status_dem {
    assert(inlist(`v', 1, 2, 3, 98, 99))
    replace `v' = . if inlist(`v', 98, 99)
}

* reverse coding so that 1 means disagree, 2 is agree somewhat, 3 is agree
foreach v of var pol_contribute opportunity status_dem {
    recode `v' (1=3) (3=1)
}

* average within states
collapse (mean) pol_contribute opportunity status_dem, by(cve_ent)
ren * *_12
ren cve_ent_12 cve_ent

* --- Merge
merge 1:1 cve_ent using `encup05', assert(match) nogen

* create differences
foreach v in pol_contribute opportunity status_dem {
    gen diff`v' = `v'_12 - `v'_05
}
ren cve_ent ent
compress
save "../data_prepped/encup", replace
