/*

Prepares IPW and employment changes.

----------------------------------------------------------------------------- */

* load programs
run ipw_pchjobs_pr

* ------------------------------------------------------------------------------
* Construct changes in exports

* --- Predicted changes in exports from China to US (4-digit industries)

* these data show value of exports from China to partners, by 4-digit industry and year, from 1996-2011
use "../data_raw/comtrade1998_2011", clear
ren tradevalueus tradevalue

* keep exports to US in 2007, 2010, and 2011
keep if partnercode == 842 & inlist(period, 2007, 2010, 2011)
reshape wide tradevalue, i(rama) j(period)

* each industry's percentage of total exports in 2007
replace tradevalue2007 = 0 if mi(tradevalue2007)
egen inishare_2007 = pc(tradevalue2007), prop

* total exports to US in 2010 and 2011
egen totalvalue2010 = total(tradevalue2010)
egen totalvalue2011 = total(tradevalue2011)

* predict export value of each industry in 2010 and 2011: total value in year t x industry's share of exports
gen ptradevalue2010 = totalvalue2010 * inishare_2007
gen ptradevalue2011 = totalvalue2011 * inishare_2007

* predicted change in China exports to US from 2007 (delta UC)
gen chexp2010 = ptradevalue2010 - tradevalue2007
gen chexp2011 = ptradevalue2011 - tradevalue2007
keep rama chexp* tradevalue2007
tempfile prd_chexp_us_4dig
save `prd_chexp_us_4dig'

* ------------------------------------------------------------------------------
* Prepare labor by Mexican municpality x industry

* --- 4-digit industry
use "../../main/data_raw/rama_municipio_totemp_emim20072011_year", clear
keep if inlist(year, 2007, 2010, 2011)
destring rama, replace
gen subs = floor(rama / 10)
tempfile emp_4dig
preplabor, outfile(`emp_4dig') indcodevar(rama)

* ------------------------------------------------------------------------------
* Prepare 2003 non-agricultural labor force to be denominator

* prep 2007 EMIM
use `emp_4dig', clear
bys id_mun: egen numobs2007 = total(!mi(totemp2007))
drop if numobs2007 == 0
collapse (sum) totemp2007, by(id_mun)
ren totemp2007 lemim07
save "../data_prepped/lemim07", replace

* merge with 2003 labor
ren id_mun municipio
merge 1:1 municipio using "../../main/data_raw/pop_manpop_municipio.dta", keepusing(L03) nogen
ren municipio id_mun
tempfile denominators
save `denominators'

* ------------------------------------------------------------------------------
* Construct changes in jobs

* --- Denominator is 2003 labor force
makepchjobs, indata_emp(`emp_4dig') indata_denom(`denominators') denomvar(L03) outfile("../data_prepped/pchjobs/l03")

* ------------------------------------------------------------------------------
* Construct instrument

* --- 4-digit, predicted exports to US, denominator is 2003 labor force
makeipw, indata_emp(`emp_4dig') indata_chexp(`prd_chexp_us_4dig') indata_denom(`denominators') denomvar(L03) indcodevar(rama) outfile("../data_prepped/ipw/prd_us_l03_4dig")
