/*

Prepares IPW and employment changes for 1998-2003.

----------------------------------------------------------------------------- */

* load program to make ipw
run ipw_pchjobs_pr

* --------- Prepare changes in exports

* these data show value of exports from China to partners, by 4-digit industry and year, from 1996-2011 (src: prepare_trade.do)
use "../data_raw/comtrade1998_2011", clear
ren tradevalueus tradevalue

* keep exports to US in 1998 and 2003
keep if partnercode == 842 & inlist(period, 1998, 2003)
reshape wide tradevalue, i(rama) j(period)

* each industry's percentage of total exports in 1998
egen inishare_1998 = pc(tradevalue1998), prop

* total exports to US in 2003
egen totalvalue2003 = total(tradevalue2003)

* predict export value of each industry in 2003: total value in year 2003 x industry's share of exports in 1998
gen ptradevalue2003 = totalvalue2003 * inishare_1998

* predicted change in China exports to US from 1998 to 2003 (delta UC)
gen chexp2003 = ptradevalue2003 - tradevalue1998
keep rama chexp2003 tradevalue1998
tempfile chexp_prd_us_4dig
save `chexp_prd_us_4dig'

* ------------------------------------------------------------------------------
* Prepare labor by Mexican municpality x industry

* --- 1998, 4-digit industry
use "../../main/data_raw/worker_by_type_ramamun_censo9803", clear
keep if inlist(year, 1998, 2003)
egen totemp = rowtotal(empleado obrero owner_family other_firm_worker), missing
gen id_municipio = real(string(ent, "%02.0f") + string(mun, "%03.0f"))
keep id_municipio rama year totemp
reshape wide totemp, i(id_municipio rama) j(year)
bys rama: egen natemp1998 = total(totemp1998), missing
tempfile emp_4dig
save `emp_4dig'

* ------------------------------------------------------------------------------
* Construct percent changes in jobs

* create municipal employment
use `emp_4dig', clear
bys id_municipio: egen mun_totemp1998 = total(totemp1998), missing
bys id_municipio: egen mun_totemp2003 = total(totemp2003), missing
keep id_municipio mun_totemp*
duplicates drop

* merge with labor in 1998
ren id_municipio id_mun
merge 1:1 id_mun using "../data_prepped/labor98", keep(match) nogen keepusing(labor98)

* create percent changes in jobs (denominator is total 1998 employment)
gen pchjobs2003 = (mun_totemp2003 - mun_totemp1998) / labor98
drop if mi(pchjobs2003)
keep id_mun pchjobs2003 mun_totemp2003 mun_totemp1998
save "../data_prepped/pchjobs/9803/l98", replace

* ------------------------------------------------------------------------------
* Construct instrument

* --- 4-digit, predicted exports to US, denominator is 1998 labor force
makeipw98, indata_emp(`emp_4dig') indata_chexp(`chexp_prd_us_4dig') indata_denom("../data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9803/prd_us_l98_4dig") endyr(2003)
