/*

Prepares IPW and employment changes for 1998-2013.

----------------------------------------------------------------------------- */

* load program to make ipw
run ipw_pchjobs_pr

* --------- Prepare changes in exports

* --- Construct changes in exports to US (predicted shares)

* keep exports to US in 1998
use "../data_raw/comtrade1998_2011", clear
keep if partnercode == 842 & period == 1998
ren tradevalueus tradevalue1998
keep rama tradevalue1998

* merge 1998 and 2013
merge 1:1 rama using "../data_prepped/comtrade_us13"
ren tradevalueus tradevalue2013
assert(mi(rama) | inlist(rama, 1112, 1114, 1121, 1123)) if _merge != 3
drop _merge

* each industry's percentage of total exports in 1998
egen inishare_1998 = pc(tradevalue1998), prop

* predict export value of each industry in 2013: total value in year 2013 x industry's share of exports in 1998
egen totalvalue2013 = total(tradevalue2013)
gen ptradevalue2013 = totalvalue2013 * inishare_1998

* predicted change in China exports to US from 1998 to 2013 (delta UC)
gen chexp2013 = ptradevalue2013 - tradevalue1998
keep rama chexp2013 tradevalue1998
tempfile prd_chexp_us_4dig
save `prd_chexp_us_4dig'

* ------------------------------------------------------------------------------
* Prepare labor by Mexican municipality x industry

* --- Prepare 1998
use "../../main/data_raw/worker_by_type_ramamun_censo9803", clear
keep if year == 1998
egen totemp = rowtotal(empleado obrero owner_family other_firm_worker)
gen id_municipio = real(string(ent, "%02.0f") + string(mun, "%03.0f"))
ren totemp totemp1998
keep id_municipio rama totemp1998
bys rama: egen natemp1998 = total(totemp1998)
tempfile emp1998
save `emp1998'

* --- Prepare 2013
use "../../main/data_raw/Censo_manuf_emp13", clear
keep id_municipio Censo_2014_manuf
duplicates drop
ren Censo_2014_manuf mun_totemp2013
tempfile emp2013
save `emp2013'

* ------------------------------------------------------------------------------
* Construct percent changes in jobs

* create municipal employment in 1998
use `emp1998', clear
bys id_municipio: egen mun_totemp1998 = total(totemp1998), missing
keep id_municipio mun_totemp1998
duplicates drop

* merge with municipal employment in 2013
merge 1:1 id_municipio using `emp2013', nogen

* merge with labor in 1998
ren id_municipio id_mun
merge 1:1 id_mun using "../data_prepped/labor98", assert(master match) keep(match) nogen keepusing(labor98 lman98)

* --- Create percent changes in jobs (denominator is total 1998 employment)
gen pchjobs2013 = (mun_totemp2013 - mun_totemp1998) / labor98
drop if mi(pchjobs2013)
keep id_mun pchjobs2013 mun_totemp2013 mun_totemp1998
save "../data_prepped/pchjobs/9813/l98", replace

* ------------------------------------------------------------------------------
* Construct IPW

* --- 4-digit, predicted exports to US, denominator is 1998 labor force
makeipw98, indata_emp(`emp1998') indata_chexp(`prd_chexp_us_4dig') indata_denom("../data_prepped/labor98") denomvar(labor98) indcodevar(rama) outfile("../data_prepped/ipw/9813/prd_us_l98_4dig") endyr(2013)
