/*

Predict what the change in homicides would have been if delta icw were zero.

----------------------------------------------------------------------------- */

* --------- Prepare data

* --- Main (2007-2010/11)
use "../data_prepped/maindata", clear

* merge with ipw
merge 1:1 id_mun using "../data_prepped/ipw/prd_us_l03_4dig", keep(match) nogen
replace ipw2010 = ipw2010 / 100000

* drop rural and save
drop if tipo_mun == "RU"
tempfile mundata_main
save `mundata_main'

* --- 1998-2003
use "../data_prepped/maindata_9803", clear

* merge with ipws
merge 1:1 id_mun using "../data_prepped/ipw/9803/prd_us_l98_4dig", keep(match) nogen
replace ipw2003 = ipw2003 / 100000

* keep emim sample
keep if emimsamp

* drop rural and save
drop if tipo_mun == "RU"
tempfile mundata_9803
save `mundata_9803'

* --- 1998-2013
use "../data_prepped/maindata_9813", clear

* merge with ipws
merge 1:1 id_mun using "../data_prepped/ipw/9813/prd_us_l98_4dig", keep(match) nogen
replace ipw2013 = ipw2013 / 100000

* keep emim sample
keep if emimsamp

* drop rural and save
drop if tipo_mun == "RU"
tempfile mundata_9813
save `mundata_9813'

* load controls
include conlist

* ------------------------------------------------------------------------------
* Predictions: all homicides

* --- Single regression
use `mundata_main', clear
regress homdiff_inegi_ratelong3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_inegi_ratelong3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(round(`pctexp', .1) == 5.4)

* --- Separate regressions for no dto, minor dto, and major dto, then aggregate
use `mundata_main', clear
gen ipw2010_orig = ipw2010
regress homdiff_inegi_ratelong3 ipw2010 `convars_main' [aw=L03] if !cartel
replace ipw2010 = 0 if e(sample)
predict homrate0_no if e(sample), xb
replace ipw2010 = ipw2010_orig
regress homdiff_inegi_ratelong3 ipw2010 `convars_main' [aw=L03] if cartel & !C_major
replace ipw2010 = 0 if e(sample)
predict homrate0_min if e(sample), xb
replace ipw2010 = ipw2010_orig
regress homdiff_inegi_ratelong3 ipw2010 `convars_main' [aw=L03] if C_major
replace ipw2010 = 0 if e(sample)
predict homrate0_maj if e(sample), xb
egen homrate0 = rowmax(homrate0*)
gen hominc_real = homdiff_inegi_ratelong3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if !mi(hominc0)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(float(round(`pctexp', .1)) == float(27.7))

* --- Separate regressions for no dto, minor dto, and major dto, but look at the share expained separately

* no dto
use `mundata_main', clear
keep if !cartel
regress homdiff_inegi_ratelong3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_inegi_ratelong3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(round(`pctexp', .1) == 1.6)

* any dto (just a check)
use `mundata_main', clear
keep if cartel
regress homdiff_inegi_ratelong3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_inegi_ratelong3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(round(`pctexp', .1) == 6.5)

* minor dto
use `mundata_main', clear
keep if cartel & !C_major
regress homdiff_inegi_ratelong3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_inegi_ratelong3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(round(`pctexp', .1) == 5.4)

* major dto
use `mundata_main', clear
keep if C_major
regress homdiff_inegi_ratelong3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_inegi_ratelong3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(round(`pctexp', .1) == 32.7)

* ---1998-2003
use `mundata_9803', clear
regress homdiff_9803 ipw2003 `convars98' [aw=labor98]
replace ipw2003 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_9803 * pop1995 / 100000
gen hominc0 = homrate0 * pop1995 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctinc = 100 * (hominc0 - hominc_real) / hominc_real
assert(float(round(`pctinc', .1)) == float(6.1))

* --- 1998-2013
use `mundata_9813', clear
regress homdiff_9813 ipw2013 `convars98' [aw=labor98]
replace ipw2013 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_9813 * pop1998 / 100000
gen hominc0 = homrate0 * pop1998 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(round(`pctexp', .1) == 18.1)

* ------------------------------------------------------------------------------
* Drug-related homicides

* --- Single regression
use `mundata_main', clear
regress homdiff_rate_long3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_rate_long3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(float(round(`pctexp', .1)) == float(6.3))

* --- Separate regressions for no dto, minor dto, and major dto, then aggregate
use `mundata_main', clear
gen ipw2010_orig = ipw2010
regress homdiff_rate_long3 ipw2010 `convars_main' [aw=L03] if !cartel
replace ipw2010 = 0 if e(sample)
predict homrate0_no if e(sample), xb
replace ipw2010 = ipw2010_orig
regress homdiff_rate_long3 ipw2010 `convars_main' [aw=L03] if cartel & !C_major
replace ipw2010 = 0 if e(sample)
predict homrate0_min if e(sample), xb
replace ipw2010 = ipw2010_orig
regress homdiff_rate_long3 ipw2010 `convars_main' [aw=L03] if C_major
replace ipw2010 = 0 if e(sample)
predict homrate0_maj if e(sample), xb
egen homrate0 = rowmax(homrate0*)
gen hominc_real = homdiff_rate_long3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if !mi(hominc0)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(float(round(`pctexp', .1)) == float(26.9))

* --- Separate regressions for no dto, minor dto, and major dto, but look at the share expained separately

* no dto
use `mundata_main', clear
keep if !cartel
regress homdiff_rate_long3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_rate_long3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(float(round(`pctexp', .1)) == float(-2.9))

* any dto (just a check)
use `mundata_main', clear
keep if cartel
regress homdiff_rate_long3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_rate_long3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(round(`pctexp', .1) == 8.0)

* minor dto
use `mundata_main', clear
keep if cartel & !C_major
regress homdiff_rate_long3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_rate_long3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(float(round(`pctexp', .1)) == float(1.4))

* major dto
use `mundata_main', clear
keep if C_major
regress homdiff_rate_long3 ipw2010 `convars_main' [aw=L03]
replace ipw2010 = 0 if e(sample)
predict homrate0, xb
gen hominc_real = homdiff_rate_long3 * pop_05 / 100000
gen hominc0 = homrate0 * pop_05 / 100000
collapse (sum) hominc_real hominc0 if e(sample)
loc pctexp = 100 * (1 - (hominc0 / hominc_real))
assert(round(`pctexp', .1) == 32.0)
