/*

Prepares main data for pre period tables in maketables.do

----------------------------------------------------------------------------- */

* --- Prepare Presidencia crime (NOTE: 2010 data only goes to Sept 2, so we drop the Sept 1-2 obs and multiply the sum from Jan-Aug by 1.5 to estimate annual homicides)
use "../data_raw/MuertesCrimen.dta", clear
ren A*o period
drop if period == 2010 & Mes == 9
collapse (sum) Muertes_Total, by(id_municipio period)
reshape wide Muertes_Total, i(id_municipio) j(period)
replace Muertes_Total2010 = Muertes_Total2010 * 1.5

* merge with 2005 population
ren id_municipio id_municipality
merge 1:1 id_municipality using "../data_raw/2005_Population_Census", keep(match) keepusing(pop_tot) nogen
ren id_municipality id_municipio
ren pop_tot pop_05

* create main homicide rate change
gen homdiff_rate_long3 = 100000 * (Muertes_Total2010 - Muertes_Total2007) / pop_05

* create base homicide rate
gen homrate_pres_2007 = 100000 * Muertes_Total2007 / pop_05
gen homrate_pres_2010 = 100000 * Muertes_Total2010 / pop_05

* save
ren Muertes_Total* hom_pres*
tempfile pres_homicides
save `pres_homicides'

* --- Prepare INEGI crime
use "../data_raw/inegi_full_data.dta", clear
collapse (sum) hom if inlist(YearEvent, 2007, 2010, 2011), by(id_municipio YearEvent)
reshape wide hom, i(id_municipio) j(YearEvent)

* merge with presidencia crime 2005 pop
merge 1:1 id_municipio using `pres_homicides', assert(master match) keep(match) nogen

* create main period changes in homicide rates
gen homdiff_inegi_ratelong4 = 100000 * (hom2011 - hom2007) / pop_05
gen homdiff_inegi_ratelong3 = 100000 * (hom2010 - hom2007) / pop_05

* create base homicide rate
gen homrate_inegi_2007 = 100000 * hom2007 / pop_05
gen homrate_inegi_2010 = 100000 * hom2010 / pop_05
gen homrate_inegi_2011 = 100000 * hom2011 / pop_05

* save
ren hom2* hom_inegi2*
tempfile all_homicides
save `all_homicides', replace

* --- Prepare drug confiscations
use "../data_raw/confiscations.dta", clear
keep id_mun period logValueDom_total logValueFor_total
keep if inlist(period, 2007, 2010, 2011)
reshape wide logValueDom_total logValueFor_total, i(id_mun) j(period)

* adjust log seizures so that it is constructed as y = log(x) if x > 0 else 0, instead of y = log(x + 1), which is what is used in the raw data
foreach year in 2007 2010 2011 {
    foreach type in For Dom {
        gen Value`type'_total`year' = exp(logValue`type'_total`year') - 1
        replace logValue`type'_total`year' = log(Value`type'_total`year') if Value`type'_total`year' > 0
        assert(logValue`type'_total`year' == 0) if Value`type'_total`year' == 0
    }
}

* create changes
gen logValueFor_total3diff = logValueFor_total2010 - logValueFor_total2007
gen logValueDom_total3diff = logValueDom_total2010 - logValueDom_total2007
gen logValueFor_total4diff = logValueFor_total2011 - logValueFor_total2007
gen logValueDom_total4diff = logValueDom_total2011 - logValueDom_total2007

* --- Merge data

* merge confiscations with homicides
ren id_mun id_municipio
merge 1:1 id_municipio using `all_homicides', assert(master match) keep(match) nogen

* 2003 labor force
ren id_mun municipio
merge 1:1 municipio using "../../main/data_raw/pop_manpop_municipio.dta", assert(master match) nogen keepusing(L03)

* 2003 manufacturing labor force
merge 1:1 municipio using "../data_raw/L_manufact03.dta", keep(master match) nogen keepusing(L_manufact03)

* 2007 EMIM labor
ren municipio id_mun
merge 1:1 id_mun using "../data_prepped/lemim07", nogen keep(master match) keepusing(lemim07)
ren id_mun municipio

* dto
ren municipio id_municipio
merge 1:1 id_municipio using "../data_raw/dto.dta", assert(using match) keep(match) nogen keepusing(cartel)

* major cartel
ren id_municipio id_mun
merge 1:1 id_mun using "../data_raw/CartelData.dta", assert(using match) keep(match) nogen keepusing(C_major rival)

* economic controls and distance to US
merge 1:1 id_mun using "../data_raw/controls_allmun.dta", assert(using match) keep(match) nogen keepusing(C_marginal C_infantMort C_ed C_distUS)

* type of municipality (says whether it is rural)
ren id_mun id_municipio
merge 1:1 id_municipio using "../../main/data_raw/mun_characteristics.dta", keep(master match) nogen keepusing(tipo_municipio)

* geographic controls
preserve
import delim using "../data_raw/geocon_mun", clear
ren id_municip id_municipio
tempfile geocon_mun_dta
save `geocon_mun_dta'
restore
merge 1:1 id_municipio using `geocon_mun_dta', assert(using match) keep(match) nogen keepusing(slope temp elev precip)

* elections
merge 1:1 id_municipio using "../data_prepped/elections0710", keep(master match) nogen keepusing(pri_power2007 pan_power2007 prd_power2007 pan_power2010 pan_gain0710 anychange0710)

* make state id
ren id_municipio id_mun
gen byte ent = floor(id_mun / 1000)

* make share of population in labor force
gen share0 = L_manufact03 / L03

* log distance to US
gen logC_distUS = log(C_distUS)

* create dummy for election control
gen elecdummy = mi(pri_power2007)
foreach v of var pri_power2007 prd_power2007 pan_power2007 {
    assert(elecdummy) if mi(`v')
    replace `v' = 0 if mi(`v')
}

* save
compress
save "../data_prepped/maindata.dta", replace
