/*

Prepares main municipality-level dataset for 1998-2013 analysis.

----------------------------------------------------------------------------- */

* --- Prepare INEGI homicides
use "../data_raw/inegi_full_data", clear
collapse (sum) hom if YearEvent == 1998, by(id_municipio)
ren id_municipio id_mun
ren hom hom1998
tempfile homicides98
save `homicides98'

* --- Prepare INEGI homicides 2013
use "../data_prepped/hom13", clear
ren id_municipio id_mun
keep id_mun hom2013
tempfile homicides13
save `homicides13'

* --- Prepare drug confiscations
use "../data_raw/confiscations.dta", clear
keep id_mun period logValueDom_total logValueFor_total
keep if inlist(period, 1998, 2011)
reshape wide logValueFor_total logValueDom_total, i(id_mun) j(period)
tempfile confiscations
save `confiscations'

* --- Prepare EMIM sample (municipalities with data in 2007 and 2010)
use "../../main/data_raw/rama_municipio_totemp_emim20072011_year.dta", clear
drop rama totemp
duplicates drop
contract municipio if inlist(year, 2007, 2010)
keep if _freq == 2
drop _freq
ren municipio id_mun
tempfile emimsample
save `emimsample'

* --- Merge data

* geographic controls
import delim using "../data_raw/geocon_mun", clear
ren id_municip id_mun
keep id_mun slope temp elev precip

* distance to US
merge 1:1 id_mun using "../data_raw/controls_allmun.dta", assert(match) keepusing(C_distUS) nogen

* rural indicator
ren id_mun id_municipio
merge 1:1 id_municipio using "../../main/data_raw/mun_characteristics.dta", keepusing(tipo_municipio) keep(match) nogen

* 1990 and 1998 population
ren id_municipio id_municipality
merge 1:1 id_mun using "../data_prepped/pop_90_10", keep(match) nogen keepusing(pop1990 pop1998)

* 1990 census income and education
merge 1:1 id_municipality using "../data_raw/1990_Population_Census", keep(match) nogen keepusing(incearn yrschool nm_incearn nm_yrschool)
gen lincearn90 = log((incearn / nm_incearn) + 1)
gen yrschool90 = yrschool / nm_yrschool
drop incearn yrschool nm_incearn nm_yrschool

* 1998 employment and share manufacturing
ren id_municipality id_mun
merge 1:1 id_mun using "../data_prepped/labor98", keep(match) keepusing(labor98 sharemanuf98 lman98) nogen

* INEGI homicides 1998
merge 1:1 id_mun using `homicides98', assert(using match) keep(match) nogen

* INEGI homicides 2013
merge 1:1 id_mun using `homicides13', assert(using match) keep(match) nogen

* confiscations
merge 1:1 id_mun using `confiscations', assert(using match) keep(match) nogen

* EMIM sample indicator (NOTE: include two additional municipalities to match INEGI's updated sample)
merge 1:1 id_mun using `emimsample'
gen emimsamp = (_merge == 3 | inlist(id_mun, 19013, 30105))
drop _merge

* 1998 mayoral elections
ren id_mun id_municipio
merge 1:1 id_municipio using "../data_prepped/elections98", keep(master match) nogen
ren id_municipio id_mun

* --- Create new variables

* base homicides
gen homrate_inegi_1998 = 100000 * hom1998 / pop1998
gen homrate_inegi_2013 = 100000 * hom2013 / pop1998

* change in homicide rate 1998-2013
gen homdiff_9813 = 100000 * (hom2013 - hom1998) / pop1998

* adjust the logs to be constructed as y = log(x) if x > 0 else 0, instead of y = log(x + 1)
foreach year in 1998 2011 {
    foreach type in For Dom {
        gen Value`type'_total`year' = exp(logValue`type'_total`year') - 1
        replace logValue`type'_total`year' = log(Value`type'_total`year') if Value`type'_total`year' > 0
        assert(logValue`type'_total`year' == 0) if Value`type'_total`year' == 0
    }
}

* change in confiscations
gen lvalfor_diff_9811 = logValueFor_total2011 - logValueFor_total1998
gen lvaldom_diff_9811 = logValueDom_total2011 - logValueDom_total1998

* make state id
gen byte ent = floor(id_mun / 1000)

* log distance to US
gen logC_distUS = log(C_distUS)

* create dummy for election control
gen elecdummy = mi(pri_power1998)
foreach v of var pri_power1998 prd_power1998 pan_power1998 {
    assert(elecdummy) if mi(`v')
    replace `v' = 0 if mi(`v')
}

* save
drop C_distUS pop1990 hom1998 hom2013 logVal*_total2011
compress
save "../data_prepped/maindata_9813", replace
