/*

Prepares main data for pre period tables in maketables.do

----------------------------------------------------------------------------- */

* --- Prepare INEGI crime
use "../data_raw/inegi_full_data.dta", clear
collapse (sum) hom if inrange(YearEvent, 1992, 2007), by(id_municipio YearEvent)
reshape wide hom, i(id_municipio) j(YearEvent)

* merge with population
ren id_municipio id_municipality
merge 1:1 id_municipality using "../data_prepped/pop_90_10", assert(match) nogen

* create base homicide rates
forvalues year = 1992(3)2004 {
    gen homrate`year' = 100000 * hom`year' / pop`year'
}

* create changes in homicide rates
forvalues startyear = 1992(3)2004 {
    loc endyear = `startyear' + 3
    gen homdiff_`startyear'_`endyear' =  100000 * (hom`endyear' - hom`startyear') / pop`startyear'
}

* save
ren id_municipality id_mun
keep id_mun homrate* homdiff_*
tempfile homicides
save `homicides', replace

* --- Prepare drug confiscations
use "../data_raw/confiscations.dta", clear
keep id_mun period logValueDom_total logValueFor_total
keep if inrange(period, 1992, 2007)
ren logValue*_total lval*
reshape wide lvalDom lvalFor, i(id_mun) j(period)

* create levels of confiscation values
foreach type in For Dom {
    forvalues year = 1992/2007 {
        gen val`type'`year' = exp(lval`type'`year') - 1
    }
}

* create changes in log confiscation values
forvalues startyear = 1992(3)2004 {
    loc endyear = `startyear' + 3
    gen lvalFor_diff_`startyear'_`endyear' = lvalFor`endyear' - lvalFor`startyear'
    gen lvalDom_diff_`startyear'_`endyear' = lvalDom`endyear' - lvalDom`startyear'
}

* keep relevant vars
keep id_mun lvalDom* lvalFor*

* --- Merge data

* merge confiscations with homicides
merge 1:1 id_mun using `homicides', assert(match) nogen

* save
compress
save "../data_prepped/maindata_preperiod.dta", replace
