/*

Prepares population for each year (interpolated) from 1990-2010.

----------------------------------------------------------------------------- */

* merge populations from each census
tempfile population
forvalues year = 1990(5)2010 {
    if inlist(`year', 1995, 2010) use "../data_raw/`year'_Population_Census", clear
    else use "../data_raw/`year'_Population_Census", clear
    keep id_municipality pop_tot
    ren pop_tot pop`year'
    cap confirm file `population'
    if !_rc merge 1:1 id_municipality using `population', nogen
    save `population', replace
}

* interpolate population for years between censuses
foreach year in 1991 1992 1993 1994 1996 1997 1998 1999 2001 2002 2003 2004 2006 2007 2008 2009 {
    loc previousyear = floor(`year' / 5) * 5
    loc nextyear = ceil(`year' / 5) * 5
    loc previousyear_weight = 1 - ((`year' - `previousyear') / 5)
    loc nextyear_weight = 1 - ((`nextyear' - `year') / 5)
    gen pop`year' = (pop`previousyear' * `previousyear_weight') + (pop`nextyear' * `nextyear_weight')
}
order *, seq
order id_municipality
compress
save "../data_prepped/pop_90_10", replace
