/*

Reports means of dependent variables in the start and end periods (i.e., 2007 and 2010, except for the state-level opinion data which uses 2005 and 2012).

----------------------------------------------------------------------------- */

* prepare data for main spec
use "../data_prepped/maindata", clear
merge 1:1 id_mun using "../data_prepped/pchjobs/l03", keep(match) nogen
merge 1:1 id_mun using "../data_prepped/ipw/prd_us_l03_4dig", keep(match) nogen
drop if tipo_mun == "RU"

* get main sample
include conlist
qui: reg pchjobs2010 ipw2010 `convars_main' [aw=L03]
gen insample = e(sample)

* --- Create homicide rates
gen homrate_pres2007 = 100000 * hom_pres2007 / pop_05
gen homrate_inegi2007 = 100000 * hom_inegi2007 / pop_05
gen homrate_pres2010 = 100000 * hom_pres2010 / pop_05
gen homrate_inegi2010 = 100000 * hom_inegi2010 / pop_05
assert(abs((homrate_pres2010 - homrate_pres2007) - homdiff_rate_long3) < 0.0001)
assert(abs((homrate_inegi2010 - homrate_inegi2007) - homdiff_inegi_ratelong3) < 0.0001)

* --- Program to report means of a variable and weight
cap program drop report_means
program report_means
    syntax [aw], ///
        meanvar(varname) /// variable for which to report mean
        [fullonly] /// only do full sample

    * full sample
    qui: summ `meanvar' [`weight'`exp'] if insample
    loc mean: di %3.2f r(mean)
    di as txt "Mean of {bf:`meanvar'}, `weight'`exp' (full sample): {bf:`mean'} (N=`=r(N)')"
    if !mi("`fullonly'") exit

    * no DTO
    qui: summ `meanvar' [`weight'`exp'] if insample & cartel == 0
    loc mean: di %3.2f r(mean)
    di as txt "Mean of {bf:`meanvar'}, `weight'`exp' (no DTO): {bf:`mean'} (N=`=r(N)')"

    * minor DTO
    qui: summ `meanvar' [`weight'`exp'] if insample & cartel == 1 & C_major == 0
    loc mean: di %3.2f r(mean)
    di as txt "Mean of {bf:`meanvar'}, `weight'`exp' (minor DTO): {bf:`mean'} (N=`=r(N)')"

    * any DTO
    qui: summ `meanvar' [`weight'`exp'] if insample & cartel == 1
    loc mean: di %3.2f r(mean)
    di as txt "Mean of {bf:`meanvar'}, `weight'`exp' (any DTO): {bf:`mean'} (N=`=r(N)')"

    * major DTO
    qui: summ `meanvar' [`weight'`exp'] if insample & C_major == 1
    loc mean: di %3.2f r(mean)
    di as txt "Mean of {bf:`meanvar'}, `weight'`exp' (major DTO): {bf:`mean'} (N=`=r(N)')"
end

tempfile templog
log using `templog'

* Presidencia 2007
report_means [aw=L03], meanvar(homrate_pres2007)

* Presidencia 2010
report_means [aw=L03], meanvar(homrate_pres2010)

* Inegi 2007
report_means [aw=L03], meanvar(homrate_inegi2007)

* Inegi 2010
report_means [aw=L03], meanvar(homrate_inegi2010)

* log value of foreign confiscations 2007
report_means [aw=L03], meanvar(logValueFor_total2007)

* log value of foreign confiscations 2010
report_means [aw=L03], meanvar(logValueFor_total2010)

* log value of domestic confiscations 2007
report_means [aw=L03], meanvar(logValueDom_total2007)

* log value of domestic confiscations 2010
report_means [aw=L03], meanvar(logValueDom_total2010)

* --- State level

* prepare data
use "../data_prepped/maindata_state", clear
gen insample = 1

* politicians improve wellbeing 2005
report_means [aw=L03], meanvar(pol_contribute_05) fullonly

* politicians improve wellbeing 2012
report_means [aw=L03], meanvar(pol_contribute_12) fullonly

* more opportunities than in past 2005
report_means [aw=L03], meanvar(opportunity_05) fullonly

* more opportunities than in past 2012
report_means [aw=L03], meanvar(opportunity_12) fullonly

* mexico is democratic 2005
report_means [aw=L03], meanvar(status_dem_05) fullonly

* mexico is democratic 2012
report_means [aw=L03], meanvar(status_dem_12) fullonly

log close
translate `templog' "../results/start_end_means.pdf", translator(smcl2pdf)
